function plot_gmsh(fname)
%
% --- WAVEWATCH III(R) Version 4.07 ---
% Script for plotting a Gmsh-formatted unstructured mesh
% Andre van der Westhuysen, Dec 2012
%
% Example:
% 
% Given a Gmsh-formatted mesh file, e.g. 'hawaii_v5.msh', 
% provide as argument the filename without siffux:
%
% plot_gmsh('hawaii_v5')
%

fid = fopen([fname '.msh']);
%Header
for i = 1:4
   dummy = fgets(fid);
end

%Read nodes
nnode = str2num((fgets(fid)));
for inode = 1:nnode
    field = str2num(fgets(fid));
    node_number(inode) = field(1);
    node_xcor(inode) = field(2);
    node_ycor(inode) = field(3);
end

%Header
for i = 1:2
   dummy = fgets(fid);
end

%Read elements
nelem = str2num((fgets(fid)));
nelem_bound = 0;
nelem_intern = 0;
for ielem = 1:nelem
    field = str2num(fgets(fid));
    if (field(2)==15)
       nelem_bound = nelem_bound+1;
       btri(nelem_bound,:) = [field(1) field(6)];
    elseif (field(2)==2)
       nelem_intern = nelem_intern+1;
       tri(nelem_intern,:) = [field(1) field(7) field(8) field(9)];
    end
end

%Plot grid using trimesh
figure(1)
trimesh(tri(:,2:4),node_xcor,node_ycor,zeros(size(node_xcor)),'EdgeColor','k','FaceColor','none','LineWidth', 0.5)
view(2)
hold on
plot(node_xcor(btri(:,2)),node_ycor(btri(:,2)),'b.','MarkerSize',10)
xlabel('Longitude (deg)')
ylabel('Latitude (deg)')
axis equal
ylim([16 25.01]);
print(gcf,'-dpng',[fname '.png'])

%Plot grid using trimesh (zoom)
figure(2)
trimesh(tri(:,2:4),node_xcor,node_ycor,zeros(size(node_xcor)),'EdgeColor','k','FaceColor','none','LineWidth', 0.5)
view(2)
hold on
plot(node_xcor(btri(:,2)),node_ycor(btri(:,2)),'b.','MarkerSize',10)
xlim([-158.4 -157.5]);
ylim([21.1 21.9]);
xlabel('Longitude (deg)')
ylabel('Latitude (deg)')
box on
print(gcf,'-dpng',[fname '_zoom.png'])
