function plot_ounf_unstr(fname,tout)
%
% --- WAVEWATCH III(R) Version 4.07 ---
% Script for plotting NetCDF field output on an unstructured mesh
% Andre van der Westhuysen, Dec 2012
%
% Example:
% 
% Given a NetCDF unstructured mesh output file produced by ww3_ounf, 
% e.g. 'ww3.200801_hs.nc', provide as argument the filename without siffux, 
% and the index of the output time. E.g. for the third output time:
%
% plot_ounf_unstr('ww3.200801_hs',3)
%

%Read output files
ncid = netcdf.open([fname '.nc'],'NC_NOWRITE');

% Get information about the contents of the file.
[numdims, numvars, numglobalatts, unlimdimID] = netcdf.inq(ncid);

for ii = 0:(numvars-1)
   % Get information about the variables in the file.
   [varname, xtype, dimids, numatts] = netcdf.inqVar(ncid,ii);
   field{ii+1}.name = varname;

   % Get variable IDs
   varid = netcdf.inqVarID(ncid,varname);

   % Get the value of all variables
   field{ii+1}.data = netcdf.getVar(ncid,varid);
end;

ntimes = length(field{3}.data);
if tout>ntimes
    display(['***ERROR: Requested time index exceeds available output times (' num2str(ntimes) ')'])
    return;
end
fac = 1e-3;

for it = tout:tout
   rundate = datenum(1990,00,01,00,00,00) + field{3}.data(it);
   figure(1)                                                               
   trisurf(field{4}.data(1:3,:)',field{1}.data,field{2}.data,fac.*double(max(field{6}.data(:,it)',0)))
   view(0,90);shading interp;     
   colormap(jet);colorbar;axis equal
   title(['H_{m0} (m): ' datestr(rundate,31)]);
   xlabel('Longitude (deg)')
   ylabel('Latitude (deg)')
   box on;
   print(gcf,'-dpng',[fname '_it' num2str(it,'%3.3d') '.png'])
end

for it = tout:tout
   rundate = datenum(1990,00,01,00,00,00) + field{3}.data(it);
   figure(2)                                                               
   trisurf(field{4}.data(1:3,:)',field{1}.data,field{2}.data,fac.*double(max(field{6}.data(:,it)',0)))
   view(0,90);shading interp;     
   colormap(jet);colorbar;axis equal
   title(['H_{m0} (m): ' datestr(rundate,31) ' (zoom)']);
   xlim([-158.4 -157.5]);
   ylim([21.1 21.9]);
   xlabel('Longitude (deg)')
   ylabel('Latitude (deg)')
   box on;
   print(gcf,'-dpng',[fname '_it' num2str(it,'%3.3d') '_zoomed.png'])
end
